---
# https://vitepress.dev/reference/default-theme-home-page
layout: home

hero:
  name: >-
    <a href="https://trendshift.io/repositories/12875" target="_blank"><img src="https://trendshift.io/api/badge/repositories/12875" alt="Soulter%2FAstrBot | Trendshift" style="width: 250px; height: 55px; margin-bottom: 16px;" width="250" height="55"/></a>
  text: "Agentic AI 助手，服务个人与群聊"
  tagline: 连接 IM / 1000+ 插件扩展 / 通用 Agent 能力编排
  actions:
    - theme: brand
      text: 快速开始
      link: /what-is-astrbot
    - theme: alt
      text: GitHub 仓库
      link: https://github.com/AstrBotDevs/AstrBot

features:
  - icon: ✨
    title: 多平台支持
    details: 可集成到 QQ、企业微信、飞书、Telegram、Discord 等多个聊天平台
  - icon: 😌
    title: 方便易用
    details: 支持多种方式部署，无需复杂的配置，配备高度可视化的管理面板
  - icon: 🧩
    title: 高扩展性
    details: 灵活易用的插件系统。
  - icon: 🌟
    title: AI
    details: 支持 OpenAI、Anthropic、Gemini 等多种大模型接入，内置知识库和 Agent 智能体
---
